# TTS_ka
This is a simple text to speech program that uses the `edge-tts` library to convert text to speech.

## Languages Supported
- Georgian
- English
- Russian

## Requirements
- [Python 3.6 or higher](https://www.python.org/downloads/)

## Installation and Usage
1. Install the package from PyPI:
    ```sh
    pip install TTS_ka
    ```
2. Usage 
    ```sh
    TTS_ka --lang ka "გამარჯობა. როგორ ხარ?"
    ```


